<?php

namespace Teknisa\EST\Services;

use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Row;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response;
use Teknisa\Model\Estoque\Entities\Lanctoestoq;
use Teknisa\Libs\Util\DateUtil;

class Ger14500CustoLogisticoService {
    
    protected $parameterBagColumns = array("CDFORNECED");
    protected $entityManager;
    protected $crudService;
    protected $environment;
    protected $connection;

    public function __construct($entityManager, $crudService, $environment) {
        $this->entityManager = $entityManager;
        $this->crudService = $crudService;
        $this->environment = $environment;
        $this->connection = $entityManager->getConnection();
    }

    public function getUnities($unities, $regions){
        $unities = count($unities) != 0 ? $unities : null;
        $regions = count($regions) != 0 ? $regions : null;
        
        $whereParams =  [ ':CDFILIAL' => $unities, ':CDREGIAO' => $regions ]; 

        $whereClause = $unities ? "CDFILIAL IN (:CDFILIAL)" : ":CDFILIAL IS NULL";
        $whereClause .= $regions ? " AND CDREGIAO IN (:CDREGIAO)" : " AND :CDREGIAO IS NULL";
        
        $filterRow = new FilterCriteria('filial', []);
        $filterRow->setWhereClause($whereClause,$whereParams);
        $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterRow, $this->parameterBagColumns);
        $rowResponse = new DTO\Response;
        $this->crudService->find($rowResponse, $newFilterCriteria);
        
        return $rowResponse->getDataSets()[0]->getRows();
    }
    
    public function getProviders($providers){
        $providers = count($providers) != 0 ? $providers : null; 
        
        $filterRow = new FilterCriteria('fornecedor', []);
        if($providers){
            $filterRow->setWhereClause("CDFORNECED IN (:CDFORNECED)", [':CDFORNECED' => $providers]);
        }else{
            $filterRow->setWhereClause(":CDFORNECED IS NULL", [':CDFORNECED' => null]);
        }
        $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterRow, $this->parameterBagColumns);
        $rowResponse = new DTO\Response;
        $this->crudService->find($rowResponse, $newFilterCriteria);
        
        return $rowResponse->getDataSets()[0]->getRows();
    }
    
    public function buildRows($row, $providers, $unities){
        $dataSet = [];
        foreach($unities as $unity){
            foreach($providers as $provider){
                $dataSet[] = [
                    "CDFILIAL" => $unity["CDFILIAL"],
                    "CDFORNECED" => $provider["CDFORNECED"],
                    "CDPRODUTO" => $row["CDPRODUTO"],
                    "DTINIVIGCLOG" => $row["DTVIGENCIA"],
                    "VRPECUSTOLOG" => (float) $row["VRPECUSTOLOG"],
                    "VRPESEGURLOG" => (float) $row["VRPESEGURLOG"],
                    "VRVRCUSTOLOG" => (float) $row["VRVRCUSTOLOG"],
                    "NRORG" => $this->environment->getNrOrgTrab(),
                    "DTINCLUSAO" => $this->environment->getCurrentTime()->format("d/m/Y"),
                    "DTULTATU" => $this->environment->getCurrentTime()->format("d/m/Y"),
                    "NRORGINCLUSAO" => $this->environment->getNrOrgTrab(),
                    "CDOPERINCLUSAO" => $this->environment->getCdOperador(),
                    "NRORGULTATU" => $this->environment->getNrOrgTrab(),
                    "CDOPERULTATU" => $this->environment->getNrOrgTrab(),
                    "IDATIVO" => "S",
                    '__is_new' => true
                ];
            }
        }
        return $dataSet;
    }
    
    public function deleteInMass($rowsToSave){
        foreach($rowsToSave as &$row){
            unset($row['VRPECUSTOLOG']);
            unset($row['VRPESEGURLOG']);
            unset($row['VRVRCUSTOLOG']);
            $row['__is_new'] = false;
        }
        $dataSet = new DataSet('custologist', $rowsToSave);
        $response = new DTO\Response;
        $this->crudService->delete($response, $dataSet);
    }
    
    public function saveInMass($rowsToSave){
        $this->crudService->save('custologist', $rowsToSave);
        $this->entityManager->flush();
    }
}