<?php

/**
 * Parcnegociologic.
 *
 * @package Logic
 * @author  erikasouza
 *
 */
class ParcnegocioLogic {

    /**
    * ################################## REGRA DE UTILIZACAO DA CLASSE #####################################
    *
    * Ao criar ou modificar um metodo, inserir phpdoc contendo descricoes do metodo, parametros e retorno.
    * Descrever o autor e data de criacao ou alteracao.
    * Verificar metodo insereParceiroPessoa nesta classe.
    *
    * Verificar identacao, nomeclatura padrao Code Sniffer.
    *
    * ######################################################################################################
    */

    private $_ParcnegocioEntity;
    private $_parceria;
    private $_tipoEstrutura;

    const CDTIPOINSCRICAO_CPF = 'CPF';
    const CDTIPOINSCRICAO_CNPJ = 'CNPJ';
    const CDTIPOINSCRICAO_LIVRE = 'LIVRE';
    const CDTIPOPARCPRINCIPAL_PESSOA = 'PESSOA';
    const CDTIPOPARCPRINCIPAL_ESTRUTURA = 'ESTRUTURA';
    const TIPOESTRUTURA_EMPRESA = 1;
    const TIPOESTRUTURA_FILIAL = 2;

    /**
     * Construtor da classe.
     */
    public function __construct(){
        $this->_ParcnegocioEntity = new ParcnegocioEntity();
        $this->_parceria = new ParceriaEntity();
        $this->_tipoEstrutura = new TipoestruturaEntity();

    }
    
    
    /**
     * retorna um sequencial para NRPARCNEGOCIO.
     *
     * @return number
     *
     * @author gustavosilva - 17/05/2012
     */
    public static function geraNovoCodigoParcnegocio(){
    	
    	return ParcnegocioEntity::geraNovoCodigoParcNegocio();
    
    	
    }
    
      /**
     * retorna um sequencial para Nrinscricaoparc.
     *
     * @return number
     *
     * @author gustavosilva - 17/05/2012
     */
	public static function geraNovoCodigoNrInscr(){
    	
    	return ParcnegocioEntity::geraNovoCodigoNrInscr();
    
    	
    }
    
     /**
     * retorna do banco o numero de inscrição do parceiro de negócio.
     *
     * @param integer $nrparcnegocio 	Numero do Parceiro de Negócio
     * @param integer $nrorg			Numero da Organização
     *
     * @return number
     *
     * @author gustavosilva - 17/05/2012
     */
    public static function selectNrinscricaoParc($nrparcnegocio, $nrorg){
    	
    	return ParcnegocioEntity::selectNrinscricaoParc($nrparcnegocio, $nrorg);
    	
    }
    
     /**
     * retorna do banco o tamanho do numero de inscrição.
     *
     * @param integer $nrparcnegocio 	Numero do Parceiro de Negócio
     * @param integer $nrorg			Numero da Organização
     *
     * @return number
     *
     * @author gustavosilva - 17/05/2012
     */
    public static function lenghNrInscricaoParc($nrparcnegocio, $nrorg){
    	
    	return ParcnegocioEntity::lenghNrInscricaoParc($nrparcnegocio, $nrorg);
    	
    }
    
     /**
     * deleta os filhos de parceiro de negócio para poder excluir o registro.
     *
     * @param integer $nrparcnegocio 	Numero do Parceiro de Negócio
     * @param integer $nrorg			Numero da Organização
     *
     * @return void
     *
     * @author gustavosilva - 17/05/2012
     */
    public static function deleteChilds($nrparcnegocio, $nrorg){
        try{
            $var = self::consultaOrcamentosDoParceiro($nrparcnegocio, $nrorg);
            if($var == '0'){
                tk_abort();
            }
            $tipos = tk_get_field_value('TIPODEPARCEIRO');
            $array = explode(',', $tipos);
            return ParceriaEntity::deleteChilds($nrparcnegocio, $array, $nrorg);
        } catch (Exception $e) {
            throw $e;
        }
    }
    
     /**
     * deleta parceria do parceiro de negócio de acordo com a where clause.
     *
     * @param integer $nrparcnegocio 	Numero do Parceiro de Negócio
     * @param integer $where			Where Clause para exclusão
     *
     * @return void
     *
     * @author gustavosilva - 17/05/2012
     */
    public static function deleteParceriaByWhere($nrparcnegocio,$where)
    {
    	ParceriaEntity::deleteParceriaByWhere($nrparcnegocio,$where);
    }


    /**
     * Retorna os registros de um determinado parceiro de neg?.
     *
     * @param integer $nrparceiro N?o do parceiro de neg?.
     * @param integer $nrorg      N?o da Organiza?.
     *
     * @return objeto|boolean
     */
    public function retornaParceiroNegocio($nrparceiro, $nrorg){
        $consulta = $this->_ParcnegocioEntity->retornaParceiroNegocio($nrparceiro, $nrorg);
        return $consulta;
    }

    /**
     * Retorna os registros de um determinado parceiro de negócio por inscrição.
     *
     * @param integer $nrinscricaoparc Nr. do parceiro de negócio.
     * @param integer $nrorg      Nr. da Organização.
     *
     * @return objeto|boolean
     */
    public function retornaParceiroPorInscricao($cdtipoinscricao, $nrinscricaoparc, $nrorg){
        $consulta = $this->_ParcnegocioEntity->retornaParceiroPorInscricao($cdtipoinscricao, $nrinscricaoparc, $nrorg);
        return $consulta;
    }

    public function manipulaParceiro($nrorg, $nrinscricaoparc, $nmprincipalparc, $nmsecundariparc, $cdtipoinscricao = 'CPF', $idativo = 'S', $idpessoafisica = 'S', $idinstituicao = 'N') {
        $parceiro = $this->retornaParceiroPorInscricao($cdtipoinscricao, $nrinscricaoparc, $nrorg);
        if ($parceiro === null) {
            $dtinclusao = TkDateTime::now()->get(TkDateTime::FORMAT_DATE);
            $parceiro = $this->_ParcnegocioEntity->incluiParcNegocio(77, $nrorg, $nmprincipalparc, $nmsecundariparc, $nrinscricaoparc,
                $cdtipoinscricao, $idativo, $dtinclusao, $idpessoafisica, $idinstituicao);
        }

        return $parceiro;
    }
    /**
     * Insere um parceiro de negocio e uma parceria para a pessoa.
     *
     * @param integer $nrOrg           Numero da organizacao.
     * @param string  $nrInscricaoParc Numero de inscricao do parceiro.
     * @param string  $nmPrincipalParc Nome principal do parceiro.
     * @param string  $nmSecundariParc Nome secundario do parceiro.
     * @param string  $dtNascPessoa    Data de nascimento do parceiro.
     *
     * @return ParcnegocioEntity
     *
     * @author tuliobraga/brunofeliciano
     *         thalesvalias - 19/04/2012 - insere na tabela de parceria tambem e outros ajustes
     */
    public function insereParceiroPessoa($nrOrg, $nrInscricaoParc, $nmPrincipalParc, $nmSecundariParc, $dtNascPessoa) {
        //throw new Exception('teste');
        if (empty($nrInscricaoParc) === true || strlen($nrInscricaoParc) < 11){
            $tipoInscricao = self::CDTIPOINSCRICAO_LIVRE;
        } else {
            $tipoInscricao = self::CDTIPOINSCRICAO_CPF;
        }


        $parceiro = Parcnegocio::retornaParceiroPorInscricao($tipoInscricao, $nrInscricaoParc, $nrOrg);

        if (empty($parceiro)) {
            $criouParceiro = $this->_ParcnegocioEntity->incluiParcNegocio(
                $nrOrg, $nmPrincipalParc, $nmSecundariParc, $nrInscricaoParc, $tipoInscricao,
                ParcnegocioEntity::IDATIVO_SIM, ParcnegocioEntity::IDPESSOAFISICA_SIM,
                ParcnegocioEntity::IDINSTITUICAO_NAO, self::CDTIPOPARCPRINCIPAL_PESSOA, $dtNascPessoa
            );

            if ($criouParceiro === true) {
                $nrInscricaoParc = $this->_ParcnegocioEntity->getNrinscricaoparc();
                $parceiro = $this->retornaParceiroPorInscricao($tipoInscricao, $nrInscricaoParc, $nrOrg);
            } else {
                tk_warning('O Parceiro de Negócio não foi inserido!');
            }
        }

        $nrParceiroNegocio = $parceiro->getNrparcnegocio();

        $this->_insereParceria(
            $nrOrg, $nrParceiroNegocio, self::CDTIPOPARCPRINCIPAL_PESSOA, ParceriaEntity::IDATIVO_SIM
        );

        return $parceiro;
    }


    /**
     * Insere um parceiro de negocio e uma parceria para a estrutura empresa ou filial.
     *
     * @param integer $nrOrg           Numero da organizacao.
     * @param string  $nrInscricaoParc Numero de inscricao do parceiro.
     * @param string  $nmPrincipalParc Nome principal do parceiro.
     * @param string  $nmSecundariParc Nome secundario do parceiro.
     * @param integer $nrTipoEstrutura   Tipo da estrutura.
     *
     * @return ParcnegocioEntity
     *
     * @author thalesvalias - 25/04/2012
     */
    public function insereParceiroEstrutura($nrOrg, $nrInscricaoParc, $nmPrincipalParc, $nmSecundariParc, $nrTipoEstrutura) {

        //retorna o tipo de estrutura
        $tipoEstrutura = $this->_tipoEstrutura->retornaTipoEstruturaPorCodigo($nrTipoEstrutura);
        $nomeTipoEstrutura = $tipoEstrutura->getNmtipoestrutura();

        if ($nomeTipoEstrutura === self::NMTIPOESTRUTURA_EMPRESA || $nomeTipoEstrutura === self::NMTIPOESTRUTURA_FILIAL) {

            $parceiroNegocio = $this->retornaParceiroPorInscricao(self::CDTIPOINSCRICAO_CNPJ, $nrInscricaoParc, $nrOrg);

            if ($parceiroNegocio === null) {

                $criouParceiro = $this->_ParcnegocioEntity->incluiParcNegocio(
                    $nrOrg, $nmPrincipalParc, $nmSecundariParc, $nrInscricaoParc, self::CDTIPOINSCRICAO_CNPJ,
                    ParcnegocioEntity::IDATIVO_SIM, ParcnegocioEntity::IDPESSOAFISICA_NAO,
                    ParcnegocioEntity::IDINSTITUICAO_SIM, self::CDTIPOPARCPRINCIPAL_ESTRUTURA, null
                );

                if ($criouParceiro === true) {

                    $parceiroNegocio = $this->retornaParceiroPorInscricao(self::CDTIPOINSCRICAO_CNPJ, $nrInscricaoParc, $nrOrg);
                } else {
                    tk_warning('O Parceiro de Negócio não foi inserido!');
                }
            }

            $nrParceiroNegocio = $parceiroNegocio->getNrparcnegocio();

                $this->_insereParceria(
                    $nrOrg, $nrParceiroNegocio, self::CDTIPOPARCPRINCIPAL_ESTRUTURA, ParceriaEntity::IDATIVO_SIM
                );
        }


        return $nrParceiroNegocio;
    }


    /**
     * Insere uma parceria para o parceiro de negocio de determinada pessoa.
     *
     * @param $nrOrg             Numero da organizacao.
     * @param $nrParceiroNegocio Numero do parceiro de negocio da pessoa.
     * @param $tipoParceiro      Tipo do Parceiro de Negocio (PESSOA).
     * @param $idAtivo           Identificador de atividade da parceria (S).
     *
     * @return void
     *
     * @author thalesvalias - 19/04/2012
     */
    private function _insereParceria($nrOrg, $nrParceiroNegocio, $tipoParceiro, $idAtivo) {

        $parceria = $this->_parceria->retornaParceriaPorTipoParceiro($nrOrg, $nrParceiroNegocio, $tipoParceiro);

        if ($parceria === null) {

            $this->_parceria->incluiParceria($nrOrg, $nrParceiroNegocio, $tipoParceiro, $idAtivo);
        }

    }


    /**
     * Atualiza determinado parceiro de negocio de acordo com alteracoes em pessoa.
     *
     * @param $nrParceiroNegocio Numero do parceiro da pessoa.
     * @param $nrOrg             Numero da organizacao.
     * @param $nomePessoa        Nome da pessoa.
     * @param $nrInscricaoPessoa Numero de inscricao da pessoa.
     * @param $dtNascPessoa      Data de nascimento dda pessoa.
     *
     * @return void
     *
     * @author thalesvalias - 19/04/2012
     *         alessandrobartels - 
     */
    public function atualizaParceiroPessoa($nrParceiroNegocio, $nrOrg, $nomePessoa, $nrInscricaoPessoa, $dtNascPessoa) {

        $parceiroNegocio = $this->_ParcnegocioEntity->retornaParceiroNegocio($nrParceiroNegocio, $nrOrg);

        if ($parceiroNegocio !== null) {

            $nomeParceiro = $parceiroNegocio->getNmprincipalparc();
            $nrInscricaoParceiro = $parceiroNegocio->getNrinscricaoparc();
            $dtNascParceiro = (string)$parceiroNegocio->getDtnascifundparc();

            if ($nomeParceiro !== $nomePessoa) {
                $parceiroNegocio->setNmprincipalparc($nomePessoa);
                $parceiroNegocio->setNmsecundariparc($nomePessoa);
            }

            if ( ($nrInscricaoParceiro !== $nrInscricaoPessoa) && (empty($nrInscricaoPessoa) === false)) {
                $parceiroNegocio->setNrinscricaoparc($nrInscricaoPessoa);
            }

            if ($dtNascParceiro !== $dtNascPessoa) {
                $parceiroNegocio->setDtnascifundparc($dtNascPessoa);
            }

            try {

                $parceiroNegocio->persist();
            } catch(Exception $e) {
                tk_message(' Exception '.$e->getLine().' : '.$e->getTrace().' - '.$e->getMessage());
                tk_warning('Não foi possível atualizar o Parceiro de Negócio referente a esta Pessoa!');
            }
        } else {
            tk_warning('Parceiro de Negócio não cadastrado para esta Pessoa!');
        }
    }


    /**
     * Retorna a consulta de Parceiros de negocio com parceria de operador.
     *
     * @return Ambigous <$sql, string>
     */
    public static function buscaParceirosOperadores(){
        $dados = ParcnegocioEntity::buscaParceirosOperadores();
        return $dados;
    }

    	/**
     * Rotina que prepara o cadastro de um novo parceiro de negócio, nele é validado o Tipo de Parceiro
     * setando o valor de CDTIPOPARCPRINCIPAL com o primeiro Tipo de Parceiro do Multi-CheckedBox.s
     *
     * @param array     tipos   Tipos de Parceiro de negócio
     *
     * @return void
     *
     * @author gustavosilva
     *         17/05/2012
     */
    public static function rotinaDeCadastro($tipos){
      	if ($tipos[0] === ''){
            throw new Exception("Marque um Tipo de Parceiro");
        }else if (in_array('CLIENTE',$tipos) === true){
            tk_set_field_value('CDTIPOPARCPRINCIPAL', 'CLIENTE');
            }else{
                foreach ($tipos as $tipo){
                    tk_set_field_value('CDTIPOPARCPRINCIPAL', $tipo);
                     break;
                }   
            }
    } 
    
     /**
     * Rotina de criação do registro de transportadora.
     *
     * @param integer $nrparcnegocio 	Numero do Parceiro de Negócio
     * @param integer $nrorg			Numero da Organização
     * @param array $transportadora 	Array de dados para transportadora
     *
     * @return TransportEntity
     *
     * @author gustavosilva
     *         17/05/2012
     */
    public function rotinaTransportadora($nrparcnegocio, $transportadora, $nrorg){

	$fornecedor = FornecedorEntity::consultaFornecedorParcnegocio($nrparcnegocio, $nrorg);
	$cdforneced = $fornecedor->getCdforneced();
		try{
			$array = TransportEntity::consultaTransportadora($nrparcnegocio, $nrorg);
			if(is_null($array) === true){
				return TransportEntity::createNewTransportadora($cdforneced, $transportadora, $nrparcnegocio);
			}else{
				return false;
			}
		}catch (Exception $e){
			throw $e;
		}

    }


     /**
     * Rotina de criação dde parceria do parceiro de negócio.
     *
     *
     * @param array	 $tipos         	Array de Tipo de Parceiro
     * @param integer	 $nrparcnegocio		Numero do parceiro de negócio
     * @param integer	 $nrorg			Numero da Organização
     * @param integer	 $cdtipoinscricao 	Código do tio de Inscrição
     * @param integer	 $nrinscricaoparc	Numero da Inscrição do parceiro
     * @param string 	 $nome			Nome Primário
     * @param string 	 $nomereduzido		Nome Secundário
     * @param date 	 $dtnascimento  	Data de Nascimento
     * @param integer 	 $cdempresa		Código da Empresa
     * @param integer 	 $nrparcnegrelac	Numero do Parceiro de Relacionamento
     *
     * @return void
     *
     * @author gustavosilva
     *         17/05/2012
     */
    public static function rotinaParceria($tipos, $nrparcnegocio, $nrorg, $cdtipoinscricao, $nrinscricaoparc, $nome, $nomereduzido, $dtnascimento, $cdempresa, $nrparcnegrelac, $transportadora, $cdsegmer){

    	try{
    		
    		$tipoinscricao = array('CPF' => 'F', 'CNPJ' => 'J', 'LIVRE' => 'I', 'CODIGO' => 'O');    		
    		if($tipoinscricao[$cdtipoinscricao] === 'O'){
    		$nrinscricaoparc = Novocodigo::geraCodigo(Ambiente::getNrorg(), 'VENDEDOR.NRINS', 5);
    		}
    		
	    	$var = explode(',', $tipos);
	    	//se não existir em parceria criar um novo registro 			
	    	foreach ($var as $tipo){	
                    $where = "NRPARCNEGOCIO = ? and CDTIPOPARCEIRO = ? and NRORG = ?";
                    $params = array($nrparcnegocio, $tipo, $nrorg);
                    $obj = ParceriaEntity::consultaParceriaByWhereOrNew($where, $params);
                    if (self::isNewItemprebase($obj) === true){
                        $obj->setNrparceria(Novocodigo::geraCodigo(Ambiente::getNrorg(), 'PARCERIA', 10));                    
                        $obj->setNrparcnegocio($nrparcnegocio);
                        $obj->setCdtipoparceiro($tipo);
                        $obj->setIdativo('S');
                        FctUtil::newEntityAudit($obj);
                        try{
                            $obj->persist();
                        }catch (Exception $e){
                            throw  $e;
                        }
                    }
	        }

	        //deleta registros existentes que não estão marcados
	  		$inwhere = implode(',', $var); 
			ParceriaEntity::deleteParceriaByWhere($nrparcnegocio, $inwhere, $nrorg);
			
			if(in_array('CLIENTE', $var)){
				$cliente = ClienteEntity::consultaClienteParcnegocio($nrparcnegocio, $nrorg);
                if(!empty($cliente)){
					ClienteEntity::createNewCliente($nrparcnegocio, $tipoinscricao[$cdtipoinscricao], $nrinscricaoparc, $nome, $nomereduzido, $nrorg, $dtnascimento, $cdsegmer);
                }
			}else{
				
				$cliente = ClienteEntity::consultaClienteParcnegocio($nrparcnegocio, $nrorg);
				if(!empty($cliente)){
					ClienteEntity::deleteClienteFromNrparcnegocio($nrparcnegocio, $nrorg);
				}
				
			}
    		if(!in_array('TRANSPORTADORA', $var)){

    			TransportEntity::deleteTransportFromCdNrparcnegocio($nrparcnegocio, $nrorg);

			}else {
				$array = TransportEntity::consultaTransportadora($nrparcnegocio, $nrorg);
				if(is_null($array) === false || empty($array) === false){

					$obj =  TransportEntity::updateTransportadora($nrparcnegocio, $transportadora, $nrorg);

				}
			}


			if(in_array('FORNECEDOR', $var)){
				$fornecedor = FornecedorEntity::consultaFornecedorParcnegocio($nrparcnegocio, $nrorg);
				if($fornecedor == null){
					FornecedorEntity::createNewFornecedor($nrparcnegocio, $tipoinscricao[$cdtipoinscricao], $nrinscricaoparc, $nome, $nomereduzido, $nrorg);
				}
			}else{
				
				$fornecedor = FornecedorEntity::consultaFornecedorParcnegocio($nrparcnegocio, $nrorg);
				if($fornecedor !== null){
					FornecedorEntity::deleteFornecedorFromNrparcnegocio($nrparcnegocio, $nrorg);
				}
				
			}
			
	 	   if(in_array('OPERADOR', $var)){
				$operador = OperadorEntity::consultaOperadorParcnegocio($nrparcnegocio, $nrorg);
				if($operador == null){
					OperadorEntity::createNewOperador($nrparcnegocio, $nome, $nomereduzido, $nrorg, $dtnascimento);
					}elseif($operador->getIdoperativo() == 'I'){
						OperadorEntity::ativaOperadorFromNrparcnegocio($nrparcnegocio, $nrorg);
				}
			}else{
				
				$operador = Operador::consultaOperadorParcnegocio($nrparcnegocio, $nrorg);
				if($operador !== null){
					OperadorEntity::desativaOperadorFromNrparcnegocio($nrparcnegocio, $nrorg);
				}
				
			}
			
    		if(in_array('FUNCIONARIO', $var)){
                    $funcionario = FuncionarioEntity::consultaFuncionarioParcnegocio($nrparcnegocio, $nrorg);
                    if($funcionario == null){
                            if($cdempresa === '' || $cdempresa === null){
                                ParceriaEntity::retiraFuncionarioFromParcnegocio($nrparcnegocio);
                                throw new Exception("Selecione uma empresa para este funcionario! ");
                            }else{
                                FuncionarioEntity::createNewFuncionario($nrparcnegocio, $nome, $nrorg, $cdempresa);
                            }
                    }
                }else{
                    $funcionario = FuncionarioEntity::consultaFuncionarioParcnegocio($nrparcnegocio, $nrorg);
                    if($funcionario !== null){
                            FuncionarioEntity::deleteFuncionarioFromNrparcnegocio($nrparcnegocio, $nrorg);
                    }
                }
                
                if(in_array('INTERLOCUTOR', $var)){
                    $interlocutor = RelacionaparcEntity::consultaInterlocutorParcnegocio($nrparcnegocio, $nrorg);
                    if(empty($interlocutor)){
                            RelacionaparcEntity::createNewInterlocutor($nrparcnegocio, $nrparcnegrelac, $nrorg);
                    }
                }else{
                    $interlocutor = RelacionaparcEntity::consultaInterlocutorParcnegocio($nrparcnegocio, $nrorg);
                    if(empty($interlocutor)){
                            RelacionaparcEntity::deleteInterlocutorFromNrparcnegocio($nrparcnegocio, $nrorg);
                    }
                }
                if(in_array('VENDEDOR', $var)){
                    $vendedor = VendedorEntity::consultaVendedorParceiro($nrparcnegocio, $nrorg);
                    if($vendedor == null){
                            VendedorEntity::createNewVendedor($nrparcnegocio, $nrorg, $nome, $nomereduzido, $tipoinscricao[$cdtipoinscricao], $nrinscricaoparc);
                    }
                }else{
                    $vendedor = VendedorEntity::consultaVendedorParceiro($nrparcnegocio, $nrorg);
                    if($vendedor !== null){
                            VendedorEntity::deleteVendedorFromNrparcnegocio($nrparcnegocio, $nrorg);
                    }
                }		
    	}catch(Exception $e){
            throw $e;
    	}	
		
		
		

    }
    

    /**
     * Consulta se existe um orçamento para o parceiro
     *
     * @param integer	 $nrparcnegocio		Numero do parceiro de negócio
     * @param integer	 $nrorg				Numero da Organização
     *
     * @return void
     *
     * @author gustavosilva
     *         17/05/2012
     */
    public static function consultaOrcamentosDoParceiro($nrparcnegocio, $nrorg){
    	$array = ParcnegocioEntity::consultaOrcamentosDoParceiro($nrparcnegocio, $nrorg);
    	if(empty($array) === false){
            throw new Exception("Para deletar esse parceiro voce deve primeiro deletar os orcamentos referentes a ele");
    	}
    	   	
    }

     /**
     * Consulta se o objeto é novo
     *
     * @param ParceriaEntity $obj		Objeto a ser consultado
     *
     * @return boolean
     *
     * @author gustavosilva
     *         17/05/2012
     */
	public static function isNewItemprebase(ParceriaEntity $obj)
    {
        if (self::isNull($obj->getNrparceria()) === true &&
            self::isNull($obj->getNrparcnegocio()) === false &&
            self::isNull($obj->getCdtipoparceiro()) === false){
                return true;
        } else {
            return false;
        }
    }

     /**
     * Consulta se o item é novo
     *
     * @param mixed $var		variavel a ser consultado
     *
     * @return boolean
     *
     * @author gustavosilva
     *         17/05/2012
     */
    public static function isNull(&$var){
        if ($var === null || $var === '') return true;
        return false;
    }
    
    
    
    
    
}